@@ -7,11 +7,15 @@ from PIL import Image
 
 try:
     import spectral
-    from spectral.io import envi
     spectral.settings.envi_support_nonlowercase_params = True
 except ImportError:
     print('Install the spectral package to work with envi files')
 
+try:
+    import scipy
+except ImportError:
+    print('Install the scipy package to work with matlab files')
+
 from .abraia import Abraia
 
 tempdir = tempfile.gettempdir()
@@ -21,7 +25,7 @@ class Multiple(Abraia):
     def __init__(self, folder=''):
         super(Multiple, self).__init__()
 
-    def load_file(self, path):
+    def cache_file(self, path):
         dest = os.path.join(tempdir, path)
         if not os.path.exists(dest):
             os.makedirs(os.path.dirname(dest), exist_ok=True)
@@ -29,8 +33,8 @@ class Multiple(Abraia):
         return dest
 
     def load_header(self, path):
-        dest = self.load_file(path)
-        return envi.read_envi_header(dest)
+        dest = self.cache_file(path)
+        return spectral.io.envi.read_envi_header(dest)
 
     def load_metadata(self, path):
         if path.lower().endswith('.hdr'):
@@ -38,15 +42,14 @@ class Multiple(Abraia):
         return super(Multiple, self).load_metadata(path)
 
     def load_envi(self, path):
-        dest = self.load_file(path)
+        dest = self.cache_file(path)
         raw = f"{dest.split('.')[0]}.raw"
         if not os.path.exists(raw):
             self.download_file(f"{path.split('.')[0]}.raw", raw)
-        return np.array(envi.open(dest, raw)[:, :, :])
+        return np.array(spectral.io.envi.open(dest, raw)[:, :, :])
 
     def load_mat(self, path):
-        from scipy.io import loadmat
-        mat = loadmat(self.load_file(path))
+        mat = scipy.io.loadmat(self.cache_file(path))
         for key, value in mat.items():
             if type(value) == np.ndarray:
                 return value
@@ -63,9 +66,9 @@ class Multiple(Abraia):
         elif path.lower().endswith('.mat'):
             img = self.load_mat(path)
         elif path.lower().endswith('.tiff') or path.lower().endswith('.tif'):
-            img = tifffile.imread(self.load_file(path))
+            img = tifffile.imread(self.cache_file(path))
         else:
-            img = np.asarray(Image.open(self.load_file(path)))
+            img = np.asarray(Image.open(self.cache_file(path)))
         if mosaic_size and len(img.shape) == 2:
             r, c = mosaic_size
             img = np.dstack([img[(k % r)::r, (k // c)::c] for k in range(r * c)])
@@ -74,15 +77,14 @@ class Multiple(Abraia):
     def save_envi(self, path, img, metadata={}):
         src = os.path.join(tempdir, path)
         os.makedirs(os.path.dirname(src), exist_ok=True)
-        envi.save_image(src, img, metadata=metadata, force=True)
+        spectral.io.envi.save_image(src, img, metadata=metadata, force=True)
         self.upload_file(f"{src.split('.')[0]}.img", f"{path.split('.')[0]}.raw")
         return self.upload_file(src, path)
 
     def save_mat(self, path, img):
-        from scipy.io import savemat
         src = os.path.join(tempdir, path)
         os.makedirs(os.path.dirname(src), exist_ok=True)
-        savemat(src, {'raw': img})
+        scipy.io.savemat(src, {'raw': img})
         return self.upload_file(src, path)
 
     def save_image(self, path, img, metadata={}):
